'use strict';

exports.__esModule = true;
exports.asyncReplace = exports.isRegExp = exports.isArray = exports.isBuffer = undefined;

var _regenerator = require('babel-runtime/regenerator');

var _regenerator2 = _interopRequireDefault(_regenerator);

var _asyncToGenerator2 = require('babel-runtime/helpers/asyncToGenerator');

var _asyncToGenerator3 = _interopRequireDefault(_asyncToGenerator2);

var _promise = require('babel-runtime/core-js/promise');

var _promise2 = _interopRequireDefault(_promise);

/**
 * async replace content
 */

var asyncReplace = exports.asyncReplace = function () {
  var ref = (0, _asyncToGenerator3.default)(_regenerator2.default.mark(function _callee() {
    var content = arguments.length <= 0 || arguments[0] === undefined ? '' : arguments[0];
    var replace = arguments[1];
    var callback = arguments[2];
    var match, promises, data, result, prevIndex;
    return _regenerator2.default.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            match = [];

            content.replace(replace, function () {
              for (var _len2 = arguments.length, args = Array(_len2), _key2 = 0; _key2 < _len2; _key2++) {
                args[_key2] = arguments[_key2];
              }

              match.push(args);
            });

            if (match.length) {
              _context.next = 4;
              break;
            }

            return _context.abrupt('return', content);

          case 4:
            promises = match.map(function (args) {
              return callback.apply(undefined, args);
            });
            _context.next = 7;
            return _promise2.default.all(promises);

          case 7:
            data = _context.sent;
            result = '', prevIndex = 0;

            match.forEach(function (item, idx) {
              var index = content.indexOf(item[0], prevIndex);
              result += content.substring(prevIndex, index) + data[idx];
              prevIndex = index + item[0].length;
            });
            result += content.substr(prevIndex);
            return _context.abrupt('return', result);

          case 12:
          case 'end':
            return _context.stop();
        }
      }
    }, _callee, this);
  }));
  return function asyncReplace(_x2, _x3, _x4) {
    return ref.apply(this, arguments);
  };
}();
/**
 * check if is remote url
 */


exports.isStream = isStream;
exports.isFunction = isFunction;
exports.isObject = isObject;
exports.isString = isString;
exports.isExist = isExist;
exports.isFile = isFile;
exports.isDirectory = isDirectory;
exports.extend = extend;
exports.getFiles = getFiles;
exports.promisify = promisify;
exports.defer = defer;
exports.md5 = md5;
exports.isRemoteUrl = isRemoteUrl;
exports.chmod = chmod;
exports.mkdir = mkdir;

var _stream = require('stream');

var _stream2 = _interopRequireDefault(_stream);

var _util = require('util');

var _util2 = _interopRequireDefault(_util);

var _crypto = require('crypto');

var _crypto2 = _interopRequireDefault(_crypto);

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _fs = require('fs');

var _fs2 = _interopRequireDefault(_fs);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * is stream
 */
function isStream(stream) {
  return !!stream && stream instanceof _stream2.default;
}

/**
 * is buffer
 */
var isBuffer = exports.isBuffer = Buffer.isBuffer;

/**
 * is array
 */
var isArray = exports.isArray = Array.isArray;

/**
 * is function
 */
function isFunction(obj) {
  return typeof obj === 'function';
}
/**
 * is object
 */
function isObject(obj) {
  return Object.prototype.toString.call(obj) === '[object Object]';
}
/**
 * is string
 */
function isString(obj) {
  return Object.prototype.toString.call(obj) === '[object String]';
}
/**
 * is regexp
 */
var isRegExp = exports.isRegExp = _util2.default.isRegExp;

/**
 * check path is exist
 */
function isExist(dir) {
  dir = _path2.default.normalize(dir);
  if (_fs2.default.accessSync) {
    try {
      _fs2.default.accessSync(dir, _fs2.default.R_OK);
      return true;
    } catch (e) {
      return false;
    }
  }
  return _fs2.default.existsSync(dir);
}

/**
 * check filepath is file
 */
function isFile(filePath) {
  if (!isExist(filePath)) {
    return false;
  }
  var stat = _fs2.default.statSync(filePath);
  return stat.isFile();
}

/**
 * check path is directory
 */
function isDirectory(filePath) {
  if (!isExist(filePath)) {
    return false;
  }
  var stat = _fs2.default.statSync(filePath);
  return stat.isDirectory();
}
/**
 * extend
 */
function extend(target, source) {
  var src = void 0,
      copy = void 0;
  if (!target) {
    target = isArray(source) ? [] : {};
  }
  if (!source) {
    return target;
  }
  for (var key in source) {
    src = target[key];
    copy = source[key];
    if (src && src === copy) {
      continue;
    }
    if (isObject(copy)) {
      target[key] = extend(src && isObject(src) ? src : {}, copy);
    } else if (isArray(copy)) {
      target[key] = extend([], copy);
    } else {
      target[key] = copy;
    }
  }
  return target;
}

/**
 * get path files
 */
function getFiles(dir) {
  var prefix = arguments.length <= 1 || arguments[1] === undefined ? '' : arguments[1];

  if (!isExist(dir)) {
    return [];
  }
  if (isFile(dir)) {
    return [dir];
  }
  var files = _fs2.default.readdirSync(dir);
  var result = [];
  files.forEach(function (item) {
    var stat = _fs2.default.statSync(_path2.default.join(dir, item));
    if (stat.isFile()) {
      result.push(_path2.default.join(prefix, item));
    } else if (stat.isDirectory()) {
      var cFiles = getFiles(_path2.default.join(dir, item), _path2.default.join(prefix, item));
      result = result.concat(cFiles);
    }
  });
  return result;
}

/**
 * make callback to promise
 */
function promisify(fn, receiver) {
  return function () {
    for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    return new _promise2.default(function (resolve, reject) {
      fn.apply(receiver, [].concat(args, [function (err, res) {
        return err ? reject(err) : resolve(res);
      }]));
    });
  };
}

/**
 * defer
 */
function defer() {
  var deferred = {};
  deferred.promise = new _promise2.default(function (resolve, reject) {
    deferred.resolve = resolve;
    deferred.reject = reject;
  });
  return deferred;
}

/**
 * md5
 */
function md5(str) {
  return _crypto2.default.createHash('md5').update(str + '', 'utf8').digest('hex');
}function isRemoteUrl(url) {
  url = url.toLowerCase();
  return url.indexOf('http://') === 0 || url.indexOf('https://') === 0 || url.indexOf('//') === 0;
}
/**
 * change mode
 */
function chmod(dir) {
  var mode = arguments.length <= 1 || arguments[1] === undefined ? '0777' : arguments[1];

  if (!isExist(dir)) {
    return false;
  }
  try {
    _fs2.default.chmodSync(dir, mode);
    return true;
  } catch (e) {
    return false;
  }
}
/**
 * make dir
 */
function mkdir(dir) {
  var mode = arguments.length <= 1 || arguments[1] === undefined ? '0777' : arguments[1];

  if (isExist(dir)) {
    return chmod(dir, mode);
  }
  var pp = _path2.default.dirname(dir);
  if (isExist(pp)) {
    try {
      _fs2.default.mkdirSync(dir, mode);
      return true;
    } catch (e) {
      return false;
    }
  }
  if (mkdir(pp, mode)) {
    return mkdir(dir, mode);
  } else {
    return false;
  }
}
//# sourceMappingURL=index.js.map